#!/bin/bash
## Request name
#SBATCH --job-name=DCMIP41_mpi

#SBATCH --partition=gpu_p1          # partition GPU choisie
#SBATCH --nodes=1                  # nombre de noeud
#SBATCH --ntasks=4                 # nombre de tache MPI (= nombre de GPU ici)
#SBATCH --ntasks-per-node=4        # nombre de tache MPI par noeud (= nombre de GPU ici)
#SBATCH --gres=gpu:4               # nombre de GPU par noeud
#SBATCH --cpus-per-task=1           # nombre de coeurs CPU par tache

## computing project
#SBATCH -A wuu@gpu
## Elapsed time limit HH:MM:SS
#SBATCH --time=00:10:00

# do not use hyperthreading
#SBATCH --hint=nomultithread
# standard outputs
#SBATCH --output=DYNAMICO%j.out
#SBATCH --error=DYNAMICO%j.out

export OMP_NUM_THREADS=1
# OpenMP binding
export OMP_PLACES=cores

# stack
export OMP_STACKSIZE=128M
ulimit -s unlimited

# move to submission directory
cd ${SLURM_SUBMIT_DIR}

# load the same modules as during compilation
source build/arch.env
module list

# cleanup execution directory and run
rm -rf gcm.log logs *.nc netcdf
date > gcm.log
ulimit -s unlimited
srun ./gcm.exe >> gcm.log
date >> gcm.log

# move output files to netcdf subdir
mkdir -p netcdf
cp gcm.log *.def netcdf
mv *.nc netcdf

# keep log files, source code and executable for debug
mkdir -p logs
cp *.xml logs
cp -pr gcm.exe logs
cp -pr build/src logs
mv xios_client_*.err xios_client_*.out gcm.log logs

